# -*- coding: utf-8 -*-

__title__ = 'drfpasswordless'
__version__ = '1.1.3'
__author__ = 'Aaron Ng'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022 Aaron Ng'

# Version synonym
VERSION = __version__

default_app_config = 'drfpasswordless.apps.DrfpasswordlessConfig'
