# Generated by Django 3.0.2 on 2020-11-17 04:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('drfpasswordless', '0004_auto_20200125_0853'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='callbacktoken',
            unique_together=set(),
        ),
    ]
