# Generated by Django 4.2.8 on 2024-02-14 11:27
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion

from drfpasswordless.settings import api_settings

if api_settings.PASSWORDLESS_USER_MODEL:
    USER_MODEL = api_settings.PASSWORDLESS_USER_MODEL
else:
    USER_MODEL = settings.AUTH_USER_MODEL


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(USER_MODEL),
        ("drfpasswordless", "0007_alter_callbacktoken_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="callbacktoken",
            name="user",
            field= models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=USER_MODEL),
        ),
    ]
