# Generated by Django 3.0.2 on 2020-01-22 08:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfpasswordless', '0002_auto_20200122_0424'),
    ]

    operations = [
        migrations.AddField(
            model_name='callbacktoken',
            name='type',
            field=models.CharField(choices=[('AUTH', 'Auth'), ('VERIFY', 'Verify')], default='VERIFY', max_length=20),
            preserve_default=False,
        ),
    ]
